| Title: | Makes a Local Population Projection |
|---|---|
| Description: | This is a sub national population projection model for calculating population development. The model uses a cohort component method. Further reading: Stanley K. Smith: A Practitioner's Guide to State and Local Population Projections. 2013. <doi:10.1007/978-94-007-7551-0>. |
| Authors: | Peter Thuresson <[email protected]> |
| Maintainer: | Peter Thuresson <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-06-06 09:23:45 UTC |
| Source: | https://github.com/cran/befproj |
This is a Data Frame with assumptions about migrations rates, deaths and births.
data("assump_data")data("assump_data")
A data frame with 1111 observations on the following 14 variables.
agea numeric vector
categorya factor with levels asdr_men asdr_women asfr inmig.rates.men inmig.rates.women intermig.net.men intermig.net.women natpop.men natpop.women outmig.rates.men outmig.rates.women
ar_1a numeric vector
ar_2a numeric vector
ar_3a numeric vector
ar_4a numeric vector
ar_5a numeric vector
ar_6a numeric vector
ar_7a numeric vector
ar_8a numeric vector
ar_9a numeric vector
ar_10a numeric vector
ar_11a numeric vector
ar_12a numeric vector
This is a Data Frame that consists of assumptions and input to the population model. The Data Frame has 14 different variables under category: age specific death rates (asdr) for men and women, age specific fertility rates for women (asfr), domestic in migration and out migration rates for men and women, international in and out net migration for men and women, and the age specific national population.
Umea kommun
data(assump_data) str(assump_data)data(assump_data) str(assump_data)
Makes a local population projection and produce results for population components
bef_components(startpop, assumptions, YEAR)bef_components(startpop, assumptions, YEAR)
startpop |
This is the start population |
assumptions |
This is a Data Frame with assumptions |
YEAR |
This is the year from which the forecast starts |
The output from return
bef_components(startpop_data,assump_data,2019)bef_components(startpop_data,assump_data,2019)
Makes a local population projection and produce results for growth per year.
bef_proj(startpop, assumptions, YEAR)bef_proj(startpop, assumptions, YEAR)
startpop |
This is the start population |
assumptions |
This is a Data Frame with assumptions |
YEAR |
This is the year from which the forecast starts |
The output from return
bef_proj(startpop_data,assump_data,2019)bef_proj(startpop_data,assump_data,2019)
Makes a local population projection and produce results for age, sex and year
bef_raw(startpop, assumptions, YEAR)bef_raw(startpop, assumptions, YEAR)
startpop |
This is the start population |
assumptions |
This is a Data Frame with assumptions |
YEAR |
This is the year from which the forecast starts |
The output from return
bef_raw(startpop_data,assump_data,2019)bef_raw(startpop_data,assump_data,2019)
This is a Data Frame with a startpopulation. The ages reaches from 0 to 100. The start year is from 2019.
data("startpop_data")data("startpop_data")
A data frame with 101 observations on the following 3 variables.
agea numeric vector
womena numeric vector
mena numeric vector
Statistiska centralbyran, SCB, Swedish statistics
data(startpop_data) str(startpop_data)data(startpop_data) str(startpop_data)